@@ -80,8 +80,9 @@ addPackageListing <- function(pdb = pkgAvail(), dcf, warnings = TRUE) {
 # blocking of a package's (re-)installation after it has been required/loaded?
 
 #' @importFrom httr GET stop_for_status content
-readDescriptionGithub <- function(repo, username, branch = "master", quiet = TRUE) {
-  if (!missing(username) && !is.null(username)) repo <- paste(username, repo, sep = "/")
+readDescriptionGithub <- function(repo, username = NULL, branch = "master", quiet = TRUE) {
+  # browser()
+  if (!is.null(username)) repo <- paste(username, repo, sep = "/")
   pkg <- sprintf("https://github.com/%s/raw/%s/DESCRIPTION", repo, branch)
   ff <- tempfile()
   on.exit(unlink(ff))
@@ -105,14 +106,14 @@ readDescriptionGithub <- function(repo, username, branch = "master", quiet = TRU
 #'   `"andrie/rrd"`
 #' @param username Optional character vector. Name of repository on github, e.g.
 #'   `"andrie/rrd"`
-#' @param branch name of branch, defaults to `"master"`
+#' @param branch name of branch, defaults to `"main"`
 
 #' @export
 #' @family github functions
 #'
 #' @example /inst/examples/example_addPackageListingGithub.R
 addPackageListingGithub <- function(
-  pdb = pkgAvail(), repo, username = NULL, branch = "master"
+  pdb = pkgAvail(), repo, username = NULL, branch = "main"
 ) {
   desc <- readDescriptionGithub(repo = repo, username = username, branch = branch)
   addPackageListing(pdb, desc)
